==> proc-10.1.77.tar.gz: proc/src/Form/ProcKeysGenerationForm.php <==
<?php

namespace Drupal\proc\Form;

use Drupal\Component\Utility\Html;
use Drupal\Component\Utility\UrlHelper;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * Generate PGP asymmetric keys.
 */
class ProcKeysGenerationForm extends ProcOpFormBase {

  /**
   * The configuration factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * ProcKeysGenerationForm form.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   */
  public function __construct(
    ConfigFactoryInterface $config_factory,
  ) {
    $this->configFactory = $config_factory;
  }

  /**
   * {@inheritdoc}
   *
   * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
   *   The Drupal service container.
   *
   * @return static
   */
  public static function create(ContainerInterface $container): static {
    return new static(
      $container->get('config.factory'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'proc_keys_generation_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $hidden_fields = [
      'public_key',
      'encrypted_private_key',
      'generation_timestamp',
      'generation_timespan',
      'browser_fingerprint',
      'proc_email',
    ];

    foreach ($hidden_fields as $hidden_field) {
      $form[$hidden_field] = ['#type' => 'hidden'];
    }

    $form['password_confirm'] = [
      '#type' => 'password_confirm',
      '#required' => TRUE,
      '#attributes' => [
        'autocomplete' => 'new-password',
      ],
    ];

    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Submit'),
    ];

    $proc_data = _proc_common_get_decryption_form_data(NULL, TRUE);

    $key_size = $this->configFactory->get('proc.settings')->get('proc-rsa-key-size');

    $form['#attached'] = [
      'library' => [
        0 => 'proc/openpgpjs',
        1 => 'proc/proc-generate-keys',
      ],
      'drupalSettings' => [
        'proc' => [
          'proc_labels' => _proc_js_labels(),
          'proc_data' => $proc_data,
          'proc_key_size' => $key_size,
        ],
      ],
    ];

    $form['#action'] = 'generate-keys';

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state): void {
    // Check if the cipher text is empty.
    $public_key = $form_state->getValue('public_key');
    if (empty($public_key)) {
      // Set error for entire form:
      $form_state->setError($form, $this->t('Unknown error on creating asymmetric keys.'));
    }
    // Check if the generated keys look like PGP keys.
    if (!str_starts_with($public_key, '-----BEGIN PGP PUBLIC KEY BLOCK-----')) {
      $form_state->setError($form, $this->t('Invalid PGP public key format.'));
    }
  }

  /**
   * {@inheritdoc}
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   *
   * @SuppressWarnings(PHPMD.StaticAccess)
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $destination = FALSE;
    $key_created = FALSE;
    $success_message = $this->t('Your key is saved.');

    $current_url = $this->getRequest()->getSchemeAndHttpHost() . $this->getRequest()->getRequestUri();

    $parse_result = UrlHelper::parse($current_url);
    if (isset($parse_result['query']['destination'])) {
      $destination = $parse_result['query']['destination'];
    }

    if (!empty($form_state->getValue('encrypted_private_key'))) {
      $keyring = [
        'privkey' => Html::escape($form_state->getValue('encrypted_private_key')),
        'pubkey' => Html::escape($form_state->getValue('public_key')),
      ];

      $config = $this->config('proc.settings');
      $key_size = $config->get('proc-rsa-key-size');

      $meta = [
        'generation_timestamp' => Html::escape($form_state->getValue('generation_timestamp')),
        'generation_timespan' => Html::escape($form_state->getValue('generation_timespan')),
        'browser_fingerprint' => Html::escape($form_state->getValue('browser_fingerprint')),
        'proc_email' => Html::escape($form_state->getValue('proc_email')),
        'key_size' => Html::escape($key_size),
      ];

      $proc = $this->createOrUpdateProcEntity(NULL);

      $proc->set('armored', $keyring)
        ->set('meta', $meta)
        ->set('label', $meta['proc_email'])
        ->save();

      $key_created = TRUE;
      if (!$destination) {
        $this->messenger()->addMessage($success_message);
      }
    }
    if (empty($form_state->getValue('encrypted_private_key'))) {
      $this->messenger()
        ->addMessage($this->t('Unknown error on the generation of the key. Please try again.'), 'error');
    }

    if ($destination && $key_created) {
      $url = Url::fromUri('internal:/' . $destination);
      $response = new RedirectResponse($url->toString());
      $response->send();
      $this->messenger()->addMessage($success_message);
    }
  }

}

==> proc-10.1.81.tar.gz: proc/src/Form/ProcKeysGenerationForm.php <==
<?php

namespace Drupal\proc\Form;

use Drupal\Component\Utility\Html;
use Drupal\Component\Utility\UrlHelper;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\proc\ProcKeyManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * Generate PGP asymmetric keys.
 */
class ProcKeysGenerationForm extends ProcOpFormBase {

  /**
   * The configuration factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The ProcKeyManager service.
   *
   * @var \Drupal\proc\ProcKeyManagerInterface
   */
  protected ProcKeyManagerInterface $procKeyManager;

  /**
   * ProcKeysGenerationForm form.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Drupal\proc\ProcKeyManagerInterface $procKeyManager
   *   The ProcKeyManager service.
   */
  public function __construct(
    ConfigFactoryInterface $config_factory,
    ProcKeyManagerInterface $procKeyManager,
  ) {
    $this->configFactory = $config_factory;
    $this->procKeyManager = $procKeyManager;
  }

  /**
   * {@inheritdoc}
   *
   * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
   *   The Drupal service container.
   *
   * @return static
   */
  public static function create(ContainerInterface $container): static {
    return new static(
      $container->get('config.factory'),
      $container->get('proc.key_manager'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'proc_keys_generation_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $hidden_fields = [
      'public_key',
      'encrypted_private_key',
      'generation_timestamp',
      'generation_timespan',
      'browser_fingerprint',
      'proc_email',
    ];

    foreach ($hidden_fields as $hidden_field) {
      $form[$hidden_field] = ['#type' => 'hidden'];
    }

    $form['password_confirm'] = [
      '#type' => 'password_confirm',
      '#required' => TRUE,
      '#attributes' => [
        'autocomplete' => 'new-password',
      ],
    ];

    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Submit'),
    ];

    $proc_data = $this->procKeyManager->getPrivKeyMetadata(NULL, TRUE);

    $key_size = $this->configFactory->get('proc.settings')->get('proc-rsa-key-size');

    $form['#attached'] = [
      'library' => [
        0 => 'proc/openpgpjs',
        1 => 'proc/proc-generate-keys',
      ],
      'drupalSettings' => [
        'proc' => [
          'proc_labels' => _proc_js_labels(),
          'proc_data' => $proc_data,
          'proc_key_size' => $key_size,
        ],
      ],
    ];

    $form['#action'] = 'generate-keys';

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state): void {
    // Check if the cipher text is empty.
    $public_key = $form_state->getValue('public_key');
    if (empty($public_key)) {
      // Set error for entire form:
      $form_state->setError($form, $this->t('Unknown error on creating asymmetric keys.'));
    }
    // Check if the generated keys look like PGP keys.
    if (!str_starts_with($public_key, '-----BEGIN PGP PUBLIC KEY BLOCK-----')) {
      $form_state->setError($form, $this->t('Invalid PGP public key format.'));
    }
  }

  /**
   * {@inheritdoc}
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   *
   * @SuppressWarnings(PHPMD.StaticAccess)
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $destination = FALSE;
    $key_created = FALSE;
    $success_message = $this->t('Your key is saved.');

    $current_url = $this->getRequest()->getSchemeAndHttpHost() . $this->getRequest()->getRequestUri();

    $parse_result = UrlHelper::parse($current_url);
    if (isset($parse_result['query']['destination'])) {
      $destination = $parse_result['query']['destination'];
    }

    if (!empty($form_state->getValue('encrypted_private_key'))) {
      $keyring = [
        'privkey' => Html::escape($form_state->getValue('encrypted_private_key')),
        'pubkey' => Html::escape($form_state->getValue('public_key')),
      ];

      $config = $this->config('proc.settings');
      $key_size = $config->get('proc-rsa-key-size');

      $meta = [
        'generation_timestamp' => Html::escape($form_state->getValue('generation_timestamp')),
        'generation_timespan' => Html::escape($form_state->getValue('generation_timespan')),
        'browser_fingerprint' => Html::escape($form_state->getValue('browser_fingerprint')),
        'proc_email' => Html::escape($form_state->getValue('proc_email')),
        'key_size' => Html::escape($key_size),
      ];

      $proc = $this->createOrUpdateProcEntity(NULL);

      $proc->set('armored', $keyring)
        ->set('meta', $meta)
        ->set('label', $meta['proc_email'])
        ->save();

      $key_created = TRUE;
      if (!$destination) {
        $this->messenger()->addMessage($success_message);
      }
    }
    if (empty($form_state->getValue('encrypted_private_key'))) {
      $this->messenger()
        ->addMessage($this->t('Unknown error on the generation of the key. Please try again.'), 'error');
    }

    if ($destination && $key_created) {
      $url = Url::fromUri('internal:/' . $destination);
      $response = new RedirectResponse($url->toString());
      $response->send();
      $this->messenger()->addMessage($success_message);
    }
  }

}
